@@ -1,5 +1,5 @@
 /* asn1.c --- Wrapper around pseudo-ASN.1 token format.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2003-2011  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -151,7 +151,11 @@ _gss_encapsulate_token_prefix (const char *prefix, size_t prefixlen,
  *   caller must release with gss_release_buffer().
  *
  * Add the mechanism-independent token header to GSS-API context token
- * data.
+ * data.  This is used for the initial token of a GSS-API context
+ * establishment sequence.  It incorporates an identifier of the
+ * mechanism type to be used on that context, and enables tokens to be
+ * interpreted unambiguously at GSS-API peers.  See further section
+ * 3.1 of RFC 2743.  This function is standardized in RFC 6339.
  *
  * Returns:
  *
@@ -162,8 +166,9 @@ _gss_encapsulate_token_prefix (const char *prefix, size_t prefixlen,
  * unspecified at the GSS-API level.
  **/
 extern OM_uint32
-gss_encapsulate_token (const gss_buffer_t input_token,
-		       const gss_OID token_oid, gss_buffer_t output_token)
+gss_encapsulate_token (gss_const_buffer_t input_token,
+		       gss_const_OID token_oid,
+		       gss_buffer_t output_token)
 {
   int rc;
 
@@ -247,7 +252,10 @@ _gss_decapsulate_token (const char *in, size_t inlen,
  *   caller must release with gss_release_buffer().
  *
  * Remove the mechanism-independent token header from an initial
- * GSS-API context token.
+ * GSS-API context token.  Unwrap a buffer in the
+ * mechanism-independent token format.  This is the reverse of
+ * gss_encapsulate_token().  The translation is loss-less, all data is
+ * preserved as is.  This function is standardized in RFC 6339.
  *
  * Return value:
  *
@@ -261,8 +269,9 @@ _gss_decapsulate_token (const char *in, size_t inlen,
  * unspecified at the GSS-API level.
  **/
 OM_uint32
-gss_decapsulate_token (const gss_buffer_t input_token,
-		       const gss_OID token_oid, gss_buffer_t output_token)
+gss_decapsulate_token (gss_const_buffer_t input_token,
+		       gss_const_OID token_oid,
+		       gss_buffer_t output_token)
 {
   gss_OID_desc tmpoid;
   char *oid = NULL, *out = NULL;
