@@ -1,5 +1,5 @@
 /* ext.c --- Implementation of GSS specific extensions.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2003-2011  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -22,30 +22,6 @@
 
 #include "internal.h"
 
-/**
- * gss_oid_equal:
- * @first_oid: (Object ID, read) First Object identifier.
- * @second_oid: (Object ID, read) First Object identifier.
- *
- * Compare two OIDs for equality.  The comparison is "deep", i.e., the
- * actual byte sequences of the OIDs are compared instead of just the
- * pointer equality.
- *
- * WARNING: This function is a GNU GSS specific extension, and is not
- * part of the official GSS API.
- *
- * Return value: Returns boolean value true when the two OIDs are
- *   equal, otherwise false.
- **/
-int
-gss_oid_equal (const gss_OID first_oid, const gss_OID second_oid)
-{
-  return first_oid && second_oid &&
-    first_oid->length == second_oid->length &&
-    memcmp (first_oid->elements, second_oid->elements,
-	    second_oid->length) == 0;
-}
-
 /**
  * gss_userok:
  * @name: (gss_name_t, read) Name to be compared.
