@@ -1,5 +1,5 @@
 /* oid.c --- Definition of static GSS-API OIDs.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2003-2011 Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -145,3 +145,24 @@ gss_OID_desc GSS_C_NT_EXPORT_NAME_static = {
 };
 
 gss_OID GSS_C_NT_EXPORT_NAME = &GSS_C_NT_EXPORT_NAME_static;
+
+/**
+ * gss_oid_equal:
+ * @first_oid: (Object ID, read) First Object identifier.
+ * @second_oid: (Object ID, read) First Object identifier.
+ *
+ * Compare two OIDs for equality.  The comparison is "deep", i.e., the
+ * actual byte sequences of the OIDs are compared instead of just the
+ * pointer equality.  This function is standardized in RFC 6339.
+ *
+ * Return value: Returns boolean value true when the two OIDs are
+ *   equal, otherwise false.
+ **/
+int
+gss_oid_equal (gss_const_OID first_oid, gss_const_OID second_oid)
+{
+  return first_oid && second_oid &&
+    first_oid->length == second_oid->length &&
+    memcmp (first_oid->elements, second_oid->elements,
+	    second_oid->length) == 0;
+}
